//#define XERR
#include "scenario.ih"

void Scenario::alterOptions()
{
    auto &options = Options::instance();

    for (auto const *ptr = g_longOpts; ptr != g_longEnd; ++ptr)
    {
        auto iter = d_scenario.findID(ptr->longName());

        if (iter == d_scenario.end())               // option not specified
            continue;
                                                    // alter the option value
        options.alter(ptr->optionChar(), iter->value());
    }

    options.inspect();
}
